# Generated by roxygen2: do not edit by hand

export(clean)
export(createCsv)
export(createRds)
export(createSpss)
export(dataFilter)
export(dataMerge)
export(dataRequest)
export(getRedcap)
export(getSurvey)
export(getTask)
export(meld)
export(mongo)
export(mongo.index)
export(mongo.rune)
export(nda)
export(ndaRequest)
export(oracle)
export(oracle.desc)
export(oracle.index)
export(oracle.query)
export(oracle.test)
export(qualtrics)
export(qualtrics.dict)
export(qualtrics.index)
export(qualtrics.rune)
export(redcap)
export(redcap.dict)
export(redcap.index)
export(redcap.rune)
export(rune)
export(scry)
export(sift)
export(sql)
export(sql.desc)
export(sql.index)
export(sql.query)
export(to.csv)
export(to.nda)
export(to.rds)
export(to.sav)
import(dplyr)
import(haven)
import(lubridate)
import(qualtRics)
importFrom(R6,R6Class)
importFrom(REDCapR,redcap_instruments)
importFrom(REDCapR,redcap_metadata_read)
importFrom(config,get)
importFrom(dplyr,"%>%")
importFrom(dplyr,bind_rows)
importFrom(dplyr,contains)
importFrom(dplyr,filter)
importFrom(dplyr,first)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,setdiff)
importFrom(future,future)
importFrom(future,multisession)
importFrom(future,plan)
importFrom(future.apply,future_lapply)
importFrom(jsonlite,toJSON)
importFrom(knitr,kable)
importFrom(lubridate,parse_date_time)
importFrom(mongolite,mongo)
importFrom(mongolite,ssl_options)
importFrom(odbc,dbConnect)
importFrom(odbc,dbDisconnect)
importFrom(odbc,dbGetInfo)
importFrom(odbc,dbGetQuery)
importFrom(odbc,dbListFields)
importFrom(odbc,dbListTables)
importFrom(parallel,detectCores)
importFrom(rlang,.data)
importFrom(stats,setNames)
importFrom(stringdist,stringdist)
importFrom(testthat,expect_true)
importFrom(testthat,test_that)
importFrom(utils,capture.output)
importFrom(utils,flush.console)
importFrom(utils,getFromNamespace)
importFrom(utils,head)
importFrom(utils,install.packages)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
