% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/createSpss.R
\name{createSpss}
\alias{createSpss}
\title{Alias for 'to.sav' (DEPRECATED)}
\usage{
createSpss(...)
}
\arguments{
\item{...}{Additional arguments passed through to \code{to.sav()}.}
}
\value{
Invisible TRUE if successful. Writes an SPSS file to the designated path and prints a message indicating
the file's location.
}
\description{
This function is deprecated. Please use 'to.sav' instead.
This is a legacy alias for the 'to.sav' function to maintain compatibility with older code.
}
\examples{
\dontrun{
# DEPRECATED - use to.sav() instead
createSpss(prl01)
}
}
