% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dataFilter.R
\name{dataFilter}
\alias{dataFilter}
\title{Alias for 'sift' (DEPRECATED)}
\usage{
dataFilter(...)
}
\arguments{
\item{...}{Additional arguments passed through to \code{sift()}.}
}
\value{
A filtered dataframe based on the provided parameters,
and containing only the columns specified in 'cols'. If no columns
are specified, returns the entire dataframe with applied row filters.
}
\description{
This function is deprecated. Please use 'sift' instead.
This is a legacy alias for the 'sift' function to maintain compatibility with older code.
}
\examples{
\dontrun{
# DEPRECATED - use sift() instead
filtered <- dataFilter(df, sex="F")
}
}
