% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getQualtrics.R
\name{getSurvey}
\alias{getSurvey}
\title{Alias for 'qualtrics' (DEPRECATED)}
\usage{
getSurvey(...)
}
\arguments{
\item{...}{Optional column names to filter for. Only rows with non-missing values
in ALL specified columns will be returned. This is useful for filtering
data to only include complete cases for specific variables of interest.}
}
\value{
A cleaned and harmonized data frame containing the survey data with superkeys first.
}
\description{
This function is deprecated. Please use 'qualtrics' instead.
This is a legacy alias for the 'qualtrics' function to maintain compatibility with older code.
}
\examples{
\dontrun{
# DEPRECATED - use qualtrics() instead
survey_data <- getSurvey("your_survey_alias")
}
}
