% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dataMerge.R
\name{dataMerge}
\alias{dataMerge}
\title{Alias for 'meld' (DEPRECATED)}
\usage{
dataMerge(...)
}
\arguments{
\item{...}{Clean data frames to be merged.}
}
\value{
A merged data frame based on the specified or common candidate keys.
}
\description{
This function is deprecated. Please use 'meld' instead.
This is a legacy alias for the 'meld' function to maintain compatibility with older code.
}
\examples{
\dontrun{
# DEPRECATED - use meld() instead
merged <- dataMerge(df1_clean, df2_clean)
}
}
