% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dataRequest.R
\name{dataRequest}
\alias{dataRequest}
\title{Alias for 'clean' (DEPRECATED)}
\usage{
dataRequest(...)
}
\arguments{
\item{...}{Strings, specifying the measures to process, which can be a Mongo collection, REDCap instrument, or Qualtrics survey.}
}
\value{
Prints the time taken for the data request process.
}
\description{
This function is deprecated. Please use 'clean' instead.
This is a legacy alias for the 'clean' function to maintain compatibility with older code.
}
\examples{
\dontrun{
# DEPRECATED - use clean() instead
prl <- dataRequest("prl")
}
}
